==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Statistics/language/lang-polish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_HITS","Odson");
define("_BROWSERS","Przegldarki");
define("_OPERATINGSYS","System operacyjny");
define("_UNKNOWN","Nieznany");
define("_OTHER","Inny / Nieznany");
define("_MISCSTATS","Rnorodne statystyki");
define("_REGUSERS","Zarejestrowanych uytkownikw:");
define("_ACTIVEAUTHORS","Aktywnych autorw:");
define("_STORIESPUBLISHED","Opublikowanych artykuw:");
define("_SACTIVETOPICS","Aktywnych tematw:");
define("_COMMENTSPOSTED","Wysanych komentarzy:");
define("_SSPECIALSECT","Sekcji specjalnych:");
define("_ARTICLESSEC","Artykuw w sekcji:");
define("_LINKSINLINKS","Linkw w dziale LINKI:");
define("_LINKSCAT","Kategorii w linkach:");
define("_NEWSWAITING","Newsw oczekujcych na publikacj:");
define("_NUKEVERSION","Wersja PHP-Nuke:");
define("_SEARCHENGINES","Wyszukiwarki");
define("_BOTS","Roboty sieciowe");
define("_STATS","Statystyki odwiedzin");
define("_RETURNBASICSTATS","Return to Basic Statistics");
define("_BACKTODETSTATS","Back to Detailed Statistics");
define("_BACKTOMAIN","Back to Main");
define("_TODAYIS","Today is");
define("_MOSTMONTH","Busiest Month");
define("_MOSTDAY","Busiest Day");
define("_MOSTHOUR","Busiest Hour");
define("_YEARLYSTATS","Yearly Stats");
define("_MONTLYSTATS","Montly Stats for");
define("_SPAGESVIEWS","Page Views");
define("_DAILYSTATS","Daily Stats for");
define("_HOURLYSTATS","Hourly Stats for");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Statistics/language/lang-polish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_HITS","Odson");
define("_BROWSERS","Przegldarki");
define("_OPERATINGSYS","System operacyjny");
define("_UNKNOWN","Nieznany");
define("_OTHER","Inny / Nieznany");
define("_MISCSTATS","Rnorodne statystyki");
define("_REGUSERS","Zarejestrowanych uytkownikw:");
define("_ACTIVEAUTHORS","Aktywnych autorw:");
define("_STORIESPUBLISHED","Opublikowanych artykuw:");
define("_SACTIVETOPICS","Aktywnych tematw:");
define("_COMMENTSPOSTED","Wysanych komentarzy:");
define("_SSPECIALSECT","Sekcji specjalnych:");
define("_ARTICLESSEC","Artykuw w sekcji:");
define("_LINKSINLINKS","Linkw w dziale LINKI:");
define("_LINKSCAT","Kategorii w linkach:");
define("_NEWSWAITING","Newsw oczekujcych na publikacj:");
define("_NUKEVERSION","Wersja PHP-Nuke:");
define("_SEARCHENGINES","Wyszukiwarki");
define("_BOTS","Roboty sieciowe");
define("_STATS","Statystyki odwiedzin");
define("_RETURNBASICSTATS","Return to Basic Statistics");
define("_BACKTODETSTATS","Back to Detailed Statistics");
define("_BACKTOMAIN","Back to Main");
define("_TODAYIS","Today is");
define("_MOSTMONTH","Busiest Month");
define("_MOSTDAY","Busiest Day");
define("_MOSTHOUR","Busiest Hour");
define("_YEARLYSTATS","Yearly Stats");
define("_MONTLYSTATS","Montly Stats for");
define("_SPAGESVIEWS","Page Views");
define("_DAILYSTATS","Daily Stats for");
define("_HOURLYSTATS","Hourly Stats for");

?>
